==> mariadb-java-client-1.6.1-sources.jar: org/mariadb/jdbc/internal/com/Packet.java <==
/*
 *
 * MariaDB Client for Java
 *
 * Copyright (c) 2012-2014 Monty Program Ab.
 * Copyright (c) 2015-2017 MariaDB Ab.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along
 * with this library; if not, write to Monty Program Ab info@montyprogram.com.
 *
 * This particular MariaDB Client for Java file is work
 * derived from a Drizzle-JDBC. Drizzle-JDBC file which is covered by subject to
 * the following copyright and notice provisions:
 *
 * Copyright (c) 2009-2011, Marcus Eriksson
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright notice, this list
 * of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice, this
 * list of conditions and the following disclaimer in the documentation and/or
 * other materials provided with the distribution.
 *
 * Neither the name of the driver nor the names of its contributors may not be
 * used to endorse or promote products derived from this software without specific
 * prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS  AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
 * OF SUCH DAMAGE.
 *
 */

package org.mariadb.jdbc.internal.com;

/**
 * Creates result packets only handles error, ok, eof and result set packets since field and row packets require a
 * previous result set stream.
 */
public class Packet {
    public static final byte ERROR = (byte) 0xff;
    public static final byte OK = (byte) 0x00;
    public static final byte EOF = (byte) 0xfe;
    public static final byte LOCAL_INFILE = (byte) 0xfb;

    //send command
    public static final byte COM_QUIT = (byte) 0x01;
    public static final byte COM_INIT_DB = (byte) 0x02;
    public static final byte COM_QUERY = (byte) 0x03;
    public static final byte COM_PING = (byte) 0x0e;
    public static final byte COM_STMT_PREPARE = (byte) 0x16;
    public static final byte COM_STMT_EXECUTE = (byte) 0x17;
    public static final byte COM_STMT_FETCH = (byte) 0x1c;
    public static final byte COM_STMT_SEND_LONG_DATA = (byte) 0x18;
    public static final byte COM_STMT_CLOSE = (byte) 0x19;
    public static final byte COM_MULTI = (byte) 0xfe;

    //prepare statement cursor flag.
    public static final byte CURSOR_TYPE_NO_CURSOR = (byte) 0x00;
    public static final byte CURSOR_TYPE_READ_ONLY = (byte) 0x01;
    public static final byte CURSOR_TYPE_FOR_UPDATE = (byte) 0x02;
    public static final byte CURSOR_TYPE_SCROLLABLE = (byte) 0x04; //reserved, but not implemented server side

}

==> mariadb-java-client-1.8.0-sources.jar: org/mariadb/jdbc/internal/com/Packet.java <==
/*
 *
 * MariaDB Client for Java
 *
 * Copyright (c) 2012-2014 Monty Program Ab.
 * Copyright (c) 2015-2017 MariaDB Ab.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along
 * with this library; if not, write to Monty Program Ab info@montyprogram.com.
 *
 * This particular MariaDB Client for Java file is work
 * derived from a Drizzle-JDBC. Drizzle-JDBC file which is covered by subject to
 * the following copyright and notice provisions:
 *
 * Copyright (c) 2009-2011, Marcus Eriksson
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright notice, this list
 * of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice, this
 * list of conditions and the following disclaimer in the documentation and/or
 * other materials provided with the distribution.
 *
 * Neither the name of the driver nor the names of its contributors may not be
 * used to endorse or promote products derived from this software without specific
 * prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS  AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
 * OF SUCH DAMAGE.
 *
 */

package org.mariadb.jdbc.internal.com;

/**
 * Creates result packets only handles error, ok, eof and result set packets since field and row packets require a
 * previous result set stream.
 */
public class Packet {
  public static final byte ERROR = (byte) 0xff;
  public static final byte OK = (byte) 0x00;
  public static final byte EOF = (byte) 0xfe;
  public static final byte LOCAL_INFILE = (byte) 0xfb;

  //send command
  public static final byte COM_QUIT = (byte) 0x01;
  public static final byte COM_INIT_DB = (byte) 0x02;
  public static final byte COM_QUERY = (byte) 0x03;
  public static final byte COM_PING = (byte) 0x0e;
  public static final byte COM_STMT_PREPARE = (byte) 0x16;
  public static final byte COM_STMT_EXECUTE = (byte) 0x17;
  public static final byte COM_STMT_FETCH = (byte) 0x1c;
  public static final byte COM_STMT_SEND_LONG_DATA = (byte) 0x18;
  public static final byte COM_STMT_CLOSE = (byte) 0x19;
  public static final byte COM_RESET_CONNECTION = (byte) 0x1f;
  public static final byte COM_STMT_BULK_EXECUTE = (byte) 0xfa;
  public static final byte COM_MULTI = (byte) 0xfe;

  //prepare statement cursor flag.
  public static final byte CURSOR_TYPE_NO_CURSOR = (byte) 0x00;
  public static final byte CURSOR_TYPE_READ_ONLY = (byte) 0x01;
  public static final byte CURSOR_TYPE_FOR_UPDATE = (byte) 0x02;
  public static final byte CURSOR_TYPE_SCROLLABLE = (byte) 0x04; //reserved, but not implemented server side

}
